summaryrefslogtreecommitdiffstats
path: root/umbrello/umbrello/codegenerator.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commit22253cd8fbc0bd2e70f32aaf1f95ea3a3e819a60 (patch)
treebabc4a761925023e16fa94633959f35d1c251887 /umbrello/umbrello/codegenerator.cpp
parent0813b39aed2cf4c84157a22c4c9594336d93d412 (diff)
downloadtdesdk-22253cd8fbc0bd2e70f32aaf1f95ea3a3e819a60.tar.gz
tdesdk-22253cd8fbc0bd2e70f32aaf1f95ea3a3e819a60.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdesdk@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'umbrello/umbrello/codegenerator.cpp')
-rw-r--r--umbrello/umbrello/codegenerator.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/umbrello/umbrello/codegenerator.cpp b/umbrello/umbrello/codegenerator.cpp
index 87c518a2..44a65c62 100644
--- a/umbrello/umbrello/codegenerator.cpp
+++ b/umbrello/umbrello/codegenerator.cpp
@@ -166,10 +166,10 @@ CodeDocumentList * CodeGenerator::getCodeDocumentList ( ) {
}
// the vanilla version
-CodeViewerDialog * CodeGenerator::getCodeViewerDialog ( TQWidget* tqparent, CodeDocument *doc,
+CodeViewerDialog * CodeGenerator::getCodeViewerDialog ( TQWidget* parent, CodeDocument *doc,
Settings::CodeViewerState state)
{
- return new CodeViewerDialog(tqparent, doc, state);
+ return new CodeViewerDialog(parent, doc, state);
}
// Other methods
@@ -227,7 +227,7 @@ void CodeGenerator::saveToXMI ( TQDomDocument & doc, TQDomElement & root ) {
}
/**
* Initialize this code generator from its tqparent UMLDoc. When this is called, it will
* (re-)generate the list of code documents for this project (generator) by checking
* for new objects/attributes which have been added or changed in the documnet. One or more
* CodeDocuments will be created/overwritten/amended as is appropriate for the given language.
@@ -261,7 +261,7 @@ void CodeGenerator::initFromParentDocument( ) {
}
/**
* Force a synchronize of this code generator, and its present contents, to that of the tqparent UMLDocument.
* "UserGenerated" code will be preserved, but Autogenerated contents will be updated/replaced
* or removed as is apppropriate.
*/
@@ -227,7 +227,7 @@ void CodeGenerator::saveToXMI ( TQDomDocument & doc, TQDomElement & root ) {
}
/**
- * Initialize this code generator from its tqparent UMLDoc. When this is called, it will
+ * Initialize this code generator from its parent UMLDoc. When this is called, it will
* (re-)generate the list of code documents for this project (generator) by checking
* for new objects/attributes which have been added or changed in the documnet. One or more
@@ -261,7 +261,7 @@ void CodeGenerator::initFromParentDocument( ) {
}
/**
- * Force a synchronize of this code generator, and its present contents, to that of the tqparent UMLDocument.
+ * Force a synchronize of this code generator, and its present contents, to that of the parent UMLDocument.
* "UserGenerated" code will be preserved, but Autogenerated contents will be updated/replaced
* or removed as is apppropriate.